# PyEPP
> A Python API on top of EPP protocol to work with registry systems.

This a Python API on [EPP](https://en.wikipedia.org/wiki/Extensible_Provisioning_Protocol) protocol to connect to
any registry systems that support EPP and work with it. It supports bellow RFCs:
- [RFC 5730 - Extensible Provisioning Protocol](https://datatracker.ietf.org/doc/html/rfc5730)
- [RFC 5731 - Domain Name Mapping](https://datatracker.ietf.org/doc/html/rfc5731)
- [RFC 5732 - Host Mapping](https://datatracker.ietf.org/doc/html/rfc5732)
- [RFC 5733 - Contact Mapping](https://datatracker.ietf.org/doc/html/rfc5733)
- [RFC 5734 - Transport over TCP](https://datatracker.ietf.org/doc/html/rfc5734)

>This is an early version and not stable yet. Please use with care.

## Installation

```sh
pip install pyepp
```

## Usage example


## Development setup


## Contributing
Please refer to [CONTRIBUTING.md]()

<!-- Markdown link & img dfn's -->
[wiki]: https://github.com/internetnz/pyepp/wiki
